@@ -11,13 +11,14 @@ gip_translatable_keys_text = ['message']
 gip_translatable_keys_quickreply = ['text', 'options','title']
 gip_translatable_keys_list = ['globalbuttons', 'title', 'items', 'subtitle', 'options']
 gip_translatable_keys_generic_card = ['message','title_0','action0_content','action0_to','title_1','action1_content','action1_to','title_2','action2_content','action2_to','title_3','action3_content','action3_to','title_4','action4_content','action4_to''title_5','action5_content','action5_to','title_6','action6_content','action6_to','title_7','action7_content','action7_to','title_8','action8_content','action8_to','title_9','action9_content','action9_to']
-gip_translatable_keys_catalogue = ['items','title','subtitle','options']
+gip_translatable_keys_catalogue = ['items','title','subtitle','options','buttons']
 insta_translatable_keys_quickreply = ['text', 'options']
 insta_translatable_keys_catalogue = ['items','title','subtitle','options']
 insta_translatable_keys_text = ['message']
+
 translatable_keys_for_channel = {
     'whatsapp':{'text':whatsapp_translatable_keys_text, 'quick_reply':whatsapp_translatable_keys_quickreply,'list':whatsapp_translatable_keys_list},
-    'gip':{'text':gip_translatable_keys_text, 'quick_reply':gip_translatable_keys_quickreply,'list':gip_translatable_keys_list,'generic_card':gip_translatable_keys_generic_card,'gip_translatable_keys_catalogue':'catalogue'},
+    'gip':{'text':gip_translatable_keys_text, 'quick_reply':gip_translatable_keys_quickreply,'list':gip_translatable_keys_list,'generic_card':gip_translatable_keys_generic_card,'catalogue':gip_translatable_keys_catalogue},
     'instagram':{'text':insta_translatable_keys_text,'quick_reply':insta_translatable_keys_quickreply,'catalogue':insta_translatable_keys_catalogue}
     }
 
