@@ -2,7 +2,6 @@ from json import loads
 from .i18n import i18n_translate
 from . import gs_global
 
-
 def show_response_card(gs_context,current_context,response_details):
     channel = gs_context['channel']
     lang_code = gs_context["slots"]['language']
@@ -35,6 +34,12 @@ def show_response_card(gs_context,current_context,response_details):
     elif response_details['card_type'] == 'generic_card':
         generic_card_json = render_generic_card(channel,response_details)
         current_context['response_queue'].append(generic_card_json)
+    elif response_details['card_type'] == 'single_select':
+        single_select_card_json = render_single_select_card(channel,response_details)
+        current_context['response_queue'].append(single_select_card_json)
+    elif response_details['card_type'] == 'multi_select':
+        multi_select_card_json = render_multi_select_card(channel,response_details)
+        current_context['response_queue'].append(multi_select_card_json)
     return
 
 def validate_list(channel,response_details):
@@ -238,7 +243,29 @@ def render_catalogue(channel,response_details):
     elif channel == 'instagram':
         catalogue_json = response_details
         catalogue_json['type'] = 'catalogue'      
-    return catalogue_json    
+    return catalogue_json
+
+def render_single_select_card(channel,response_details):
+    single_select_json = {}
+    if channel == 'whatsapp':
+        raise Exception('Single select is not supported in Whatsapp yet!')
+    elif channel == 'gip':
+        single_select_json = response_details
+        single_select_json['type'] = 'single_select'
+    elif channel == 'instagram':
+        raise Exception('Single select is not supported in Instagram yet!')     
+    return single_select_json
+
+def render_multi_select_card(channel,response_details):
+    multi_select_json = {}
+    if channel == 'whatsapp':
+        raise Exception('Multi select is not supported in Whatsapp yet!')
+    elif channel == 'gip':
+        multi_select_json = response_details
+        multi_select_json['type'] = 'multi_select'
+    elif channel == 'instagram':
+        raise Exception('Multi select is not supported in Instagram yet!')     
+    return multi_select_json     
 
 def behave_extract_bot_response_text(channel,bot_response):
     if channel == 'whatsapp':
@@ -877,4 +904,46 @@ def behave_compare_generic_card_media(channel,input_content,bot_resp):
                 return False, reason
         return True, None
 
-    
+def behave_extract_bot_response_single_select(channel,bot_response):
+    if channel == 'whatsapp':
+        raise Exception("Single select cards are not supported on Whatsapp!")
+    elif channel == 'gip':
+        bot_resp = loads(bot_response[0]['text'])
+        return bot_resp['content'],bot_resp['options']
+
+def behave_compare_single_select(channel,input_content,bot_resp):
+    if channel == 'whatsapp':
+        raise Exception("Single select cards are not supported on Whatsapp!")
+    elif channel == 'gip':
+        input_content_key = input_content['content']
+        input_options = input_content['options']
+        if input_content_key != bot_resp[0]:
+            reason = "Values for content key did not match!"
+            return False,reason    
+        elif sorted(input_options) != sorted(bot_resp[1]):
+            reason = "Values for options key did not match!"
+            return False,reason
+        else:
+            return True,None
+
+def behave_extract_bot_response_multi_select(channel,bot_response):
+    if channel == 'whatsapp':
+        raise Exception("Multi select cards are not supported on Whatsapp!")
+    elif channel == 'gip':
+        bot_resp = loads(bot_response[0]['text'])
+        return bot_resp['content'],bot_resp['options']
+
+def behave_compare_multi_select(channel,input_content,bot_resp):
+    if channel == 'whatsapp':
+        raise Exception("Multi select cards are not supported on Whatsapp!")
+    elif channel == 'gip':
+        input_content_key = input_content['content']
+        input_options = input_content['options']
+        if input_content_key != bot_resp[0]:
+            reason = "Values for content key did not match!"
+            return False,reason
+        for dict in input_options:
+            if dict not in bot_resp[1]:
+                reason = "Values for options key did not match!"
+                return False,reason                    
+        return True,None             
\ No newline at end of file
